@@ -8,14 +8,16 @@ function(X,Y,maxNoVariables=10,maxNoVariablesSimult=5){
         lobs <- coef(glmnet(X,Y,family= if(!is.factor(Y)) "gaussian" else "binomial"))[-1,]
         nnz <- apply(lobs!=0,2,sum)
         nnzsel <- 0
+        usevarcandidate <- numeric(0)
         usevar <- numeric(0)
-        while(length(usevar)<maxNoVariables & nnzsel<max(nnz)){
+        while(length(usevarcandidate)<maxNoVariables & nnzsel<max(nnz)){
             nnzsel <- nnzsel+1
             sel <- which( nnz==nnzsel)
-            if(length(sel)>0) usevar <- sort(unique(c(usevar, which(apply(lobs[,sel,drop=FALSE]!=0,1,any)))))
+            if(length(sel)>0) usevarcandidate <- sort(unique(c(usevarcandidate, which(apply(lobs[,sel,drop=FALSE]!=0,1,any)))))
+            if(length(usevarcandidate)<=maxNoVariables) usevar <- usevarcandidate
         }
+        # the following applies if several variables enter at once
     }
-    
     testsets <- list()
     if(length(usevar)>0){
         for (ic in ((1:2^length(usevar))-1)){
